==> mailjet-client-4.1.1-sources.jar: com/mailjet/client/resource/Liststatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 *
 * @author Guillaume Badi
 */
public class Liststatistics {

    public static Resource resource = new Resource("liststatistics", "");

	public static String ACTIVECOUNT = "ActiveCount";
	public static String ACTIVEUNSUBSCRIBEDCOUNT = "ActiveUnsubscribedCount";
	public static String ADDRESS = "Address";
	public static String BLOCKEDCOUNT = "BlockedCount";
	public static String BOUNCEDCOUNT = "BouncedCount";
	public static String CLICKEDCOUNT = "ClickedCount";
	public static String CREATEDAT = "CreatedAt";
	public static String DELIVEREDCOUNT = "DeliveredCount";
	public static String ID = "ID";
	public static String ISDELETED = "IsDeleted";
	public static String LASTACTIVITYAT = "LastActivityAt";
	public static String NAME = "Name";
	public static String OPENEDCOUNT = "OpenedCount";
	public static String SPAMCOMPLAINTCOUNT = "SpamComplaintCount";
	public static String SUBSCRIBERCOUNT = "SubscriberCount";
	public static String UNSUBSCRIBEDCOUNT = "UnsubscribedCount";
	public static String CALCACTIVE = "CalcActive";
	public static String CALCACTIVEUNSUB = "CalcActiveUnsub";
	public static String CONTACTSLISTID = "ContactsListID";
	public static String EXCLUDEID = "ExcludeID";
	public static String NAMECI = "NameCI";
	public static String NAMELIKE = "NameLike";
	public static String NAMELIKECI = "NameLikeCI";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";

}

==> mailjet-client-4.5.0-sources.jar: com/mailjet/client/resource/Liststatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 * This endpoint will be deprecated as of 1st of july 2018. We advise to implement /statcounters endpoint instead.
 * @author Guillaume Badi
 */
@Deprecated
public class Liststatistics {

    public static Resource resource = new Resource("liststatistics", "");

	public static String ACTIVECOUNT = "ActiveCount";
	public static String ACTIVEUNSUBSCRIBEDCOUNT = "ActiveUnsubscribedCount";
	public static String ADDRESS = "Address";
	public static String BLOCKEDCOUNT = "BlockedCount";
	public static String BOUNCEDCOUNT = "BouncedCount";
	public static String CLICKEDCOUNT = "ClickedCount";
	public static String CREATEDAT = "CreatedAt";
	public static String DELIVEREDCOUNT = "DeliveredCount";
	public static String ID = "ID";
	public static String ISDELETED = "IsDeleted";
	@Deprecated
	public static String LASTACTIVITYAT = "LastActivityAt";
	public static String NAME = "Name";
	public static String OPENEDCOUNT = "OpenedCount";
	public static String SPAMCOMPLAINTCOUNT = "SpamComplaintCount";
	public static String SUBSCRIBERCOUNT = "SubscriberCount";
	public static String UNSUBSCRIBEDCOUNT = "UnsubscribedCount";
	public static String CALCACTIVE = "CalcActive";
	public static String CALCACTIVEUNSUB = "CalcActiveUnsub";
	public static String CONTACTSLISTID = "ContactsListID";
	public static String EXCLUDEID = "ExcludeID";
	public static String NAMECI = "NameCI";
	public static String NAMELIKE = "NameLike";
	public static String NAMELIKECI = "NameLikeCI";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";
	public static final String SOFTBOUNCEDCOUNT = "SoftbouncedCount";
	public static final String HARDBOUNCEDCOUNT = "HardbouncedCount";
	public static final String DEFERREDCOUNT = "DeferredCount";
	public static final String BLOCKED = "Blocked";
	public static final String BOUNCED = "Bounced";
	public static final String MAXLASTACTIVITYAT = "MaxLastActivityAt";
	public static final String MINLASTACTIVITYAT = "MinLastActivityAt";
	public static final String OPEN = "Open";
	public static final String QUEUED = "Queued";
	public static final String SENT = "Sent";
	public static final String SPAM = "Spam";
	public static final String UNSUBSCRIBED = "Unsubscribed";

}
